@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "faff-theme" "3.8"
+(define-package "faff-theme" "3.9.1"
   "Light Emacs color theme on cornsilk3 background."
   ()
   :url "https://github.com/WJCFerguson/emacs-faff-theme"
-  :commit "e8b6b4b5669fb41f0dd4fdcbcb88b5b9ab803f53"
-  :revdesc "e8b6b4b5669f"
+  :commit "216b52467e2fbbc61b746c28b5d0bc001345a8eb"
+  :revdesc "216b52467e2f"
   :keywords '("color" "theme")
   :authors '(("James Ferguson" . ""))
   :maintainers '(("James Ferguson" . "")))
